@@ -10,24 +10,10 @@ use Mail::Mbox::MessageParser;
 
 @ISA = qw( Exporter );
 @EXPORT = qw( CheckDiffs DoDiff InitializeCache ModuleInstalled %PROGRAMS
-  Broken_Pipe No_such_file_or_directory $single_quote $command_separator
-  $set_env
+  Broken_Pipe No_such_file_or_directory
 );
 
-use vars qw( %PROGRAMS $single_quote $command_separator $set_env );
-
-if ($^O eq 'MSWin32')
-{
-  $set_env = 'set';
-  $single_quote = '"';
-  $command_separator = '&';
-}
-else
-{
-  $set_env = '';
-  $single_quote = "'";
-  $command_separator = '';
-}
+use vars qw( %PROGRAMS );
 
 %PROGRAMS = (
  'tzip' => undef,
@@ -108,6 +94,7 @@ sub DoDiff
   {
     print "Output $output_filename looks good.\n";
 
+    unlink "$output_filename";
     unlink "$output_filename.diff";
     return (1,1);
   }
